@@ -6,6 +6,9 @@
 #include <QFile>
 #include <QStringListModel>
 
+#include <wobjectimpl.h>
+W_OBJECT_IMPL(QLuaCompleter)
+
 QLuaCompleter::QLuaCompleter(QObject *parent) : QCompleter(parent)
 {
     // Setting up GLSL types
