@@ -34,6 +34,7 @@
 
 CMT_PRAGMA_MSVC(warning(push))
 CMT_PRAGMA_MSVC(warning(disable : 5051))
+CMT_PRAGMA_MSVC(warning(disable : 4244))
 
 namespace kfr
 {
@@ -53,6 +54,18 @@ KFR_INTRINSIC vec_shape<T, Nout> low(vec_shape<T, N>)
     return {};
 }
 
+template <typename T, size_t N, size_t Nout = N / 2>
+KFR_INTRINSIC vec<T, Nout> lowhalf(const vec<T, N>& x)
+{
+    return x.shuffle(csizeseq<Nout>);
+}
+
+template <typename T, size_t N, size_t Nout = N / 2>
+KFR_INTRINSIC vec_shape<T, Nout> lowhalf(vec_shape<T, N>)
+{
+    return {};
+}
+
 template <typename T, size_t N, size_t Nout = N - prev_poweroftwo(N - 1)>
 KFR_INTRINSIC vec<T, Nout> high(const vec<T, N>& x)
 {
@@ -65,6 +78,18 @@ KFR_INTRINSIC vec_shape<T, Nout> high(vec_shape<T, N>)
     return {};
 }
 
+template <typename T, size_t N, size_t Nout = N - N / 2>
+KFR_INTRINSIC vec<T, Nout> highhalf(const vec<T, N>& x)
+{
+    return x.shuffle(csizeseq<Nout, N / 2>);
+}
+
+template <typename T, size_t N, size_t Nout = N - N / 2>
+KFR_INTRINSIC vec_shape<T, Nout> highhalf(vec_shape<T, N>)
+{
+    return {};
+}
+
 template <typename T, size_t... Ns>
 KFR_INTRINSIC vec<T, csum<size_t, Ns...>()> concat(const vec<T, Ns>&... vs) CMT_NOEXCEPT
 {
@@ -92,7 +117,7 @@ KFR_INTRINSIC vec<T, N * 4> concat4(const vec<T, N>& a, const vec<T, N>& b, cons
                                 vec<T, N>::scalar_size()>(c.v, d.v));
 }
 
-template <size_t count, typename T, size_t N, size_t Nout = N* count>
+template <size_t count, typename T, size_t N, size_t Nout = N * count>
 KFR_INTRINSIC vec<T, Nout> repeat(const vec<T, N>& x)
 {
     return x.shuffle(csizeseq<Nout> % csize<N>);
@@ -244,7 +269,7 @@ KFR_INTRINSIC vec<T, count> concat_and_slice(const vec<T, N1>& x, const vec<T, N
 template <size_t start, size_t count, typename T, size_t N1, size_t N2, KFR_ENABLE_IF(N1 < N2)>
 KFR_INTRINSIC vec<T, count> concat_and_slice(const vec<T, N1>& x, const vec<T, N2>& y)
 {
-    return x.shuffle(csizeseq<N2, -(N2 - N1)>)
+    return x.shuffle(csizeseq<N2, N1 - N2>)
         .shuffle(y, csizeseq<N2 * 2>)
         .shuffle(csizeseq<count, N2 - N1 + start>);
 }
@@ -365,12 +390,12 @@ namespace internal
 template <typename T, size_t N>
 KFR_INTRINSIC mask<T, N> evenmask()
 {
-    return broadcast<N>(maskbits<T>(true), maskbits<T>(false));
+    return mask<T, N>(broadcast<N>(maskbits<T>(true), maskbits<T>(false)));
 }
 template <typename T, size_t N>
 KFR_INTRINSIC mask<T, N> oddmask()
 {
-    return broadcast<N>(maskbits<T>(false), maskbits<T>(true));
+    return mask<T, N>(broadcast<N>(maskbits<T>(false), maskbits<T>(true)));
 }
 } // namespace internal
 
@@ -461,7 +486,7 @@ KFR_INTRINSIC vec<T, N> transpose(const vec<T, N>& x)
 template <typename T, size_t N>
 KFR_INTRINSIC vec<vec<T, N>, N> transpose(const vec<vec<T, N>, N>& x)
 {
-    return vec<vec<T, N>, N>::from_flatten(transpose<2>(x.flatten()));
+    return vec<vec<T, N>, N>::from_flatten(transpose<N>(x.flatten()));
 }
 KFR_FN(transpose)
 
