@@ -8,58 +8,56 @@
 #include "examples/ocr.hpp"
 #include <rapidfuzz/distance.hpp>
 
-template <typename T>
-std::basic_string<T> str_multiply(std::basic_string<T> a, unsigned int b)
-{
-    std::basic_string<T> output;
-    while (b--)
-        output += a;
-
-    return output;
-}
+#include "../common.hpp"
 
 template <typename Sentence1, typename Sentence2>
-int64_t levenshtein_distance(const Sentence1& s1, const Sentence2& s2,
+size_t levenshtein_distance(const Sentence1& s1, const Sentence2& s2,
                              rapidfuzz::LevenshteinWeightTable weights = {1, 1, 1},
-                             int64_t max = std::numeric_limits<int64_t>::max())
+                             size_t max = std::numeric_limits<size_t>::max())
 {
-    int64_t res1 = rapidfuzz::levenshtein_distance(s1, s2, weights, max);
-    int64_t res2 = rapidfuzz::levenshtein_distance(s1.begin(), s1.end(), s2.begin(), s2.end(), weights, max);
+    size_t res1 = rapidfuzz::levenshtein_distance(s1, s2, weights, max);
+    size_t res2 = rapidfuzz::levenshtein_distance(s1.begin(), s1.end(), s2.begin(), s2.end(), weights, max);
+    size_t res3 = rapidfuzz::levenshtein_distance(
+        BidirectionalIterWrapper(s1.begin()), BidirectionalIterWrapper(s1.end()),
+        BidirectionalIterWrapper(s2.begin()), BidirectionalIterWrapper(s2.end()), weights, max);
     rapidfuzz::CachedLevenshtein scorer(s1, weights);
-    int64_t res3 = scorer.distance(s2, max);
-    int64_t res4 = scorer.distance(s2.begin(), s2.end(), max);
+    size_t res4 = scorer.distance(s2, max);
+    size_t res5 = scorer.distance(s2.begin(), s2.end(), max);
 #ifdef RAPIDFUZZ_SIMD
     if (weights.delete_cost == 1 && weights.insert_cost == 1 && weights.replace_cost == 1 && s1.size() <= 64)
     {
-        std::vector<int64_t> results(256 / 8);
+        std::vector<size_t> results(256 / 8);
 
         if (s1.size() <= 8) {
             rapidfuzz::experimental::MultiLevenshtein<8> simd_scorer(1);
             simd_scorer.insert(s1);
             simd_scorer.distance(&results[0], results.size(), s2, max);
+            REQUIRE(res1 == results[0]);
         }
-        else if (s1.size() <= 16) {
+        if (s1.size() <= 16) {
             rapidfuzz::experimental::MultiLevenshtein<16> simd_scorer(1);
             simd_scorer.insert(s1);
             simd_scorer.distance(&results[0], results.size(), s2, max);
+            REQUIRE(res1 == results[0]);
         }
-        else if (s1.size() <= 32) {
+        if (s1.size() <= 32) {
             rapidfuzz::experimental::MultiLevenshtein<32> simd_scorer(1);
             simd_scorer.insert(s1);
             simd_scorer.distance(&results[0], results.size(), s2, max);
+            REQUIRE(res1 == results[0]);
         }
-        else {
+        if (s1.size() <= 64) {
             rapidfuzz::experimental::MultiLevenshtein<64> simd_scorer(1);
             simd_scorer.insert(s1);
             simd_scorer.distance(&results[0], results.size(), s2, max);
+            REQUIRE(res1 == results[0]);
         }
-
-        REQUIRE(res1 == results[0]);
     }
 #endif
     REQUIRE(res1 == res2);
     REQUIRE(res1 == res3);
     REQUIRE(res1 == res4);
+    REQUIRE(res1 == res5);
     return res1;
 }
 
@@ -77,12 +75,16 @@ double levenshtein_normalized_similarity(const Sentence1& s1, const Sentence2& s
     double res1 = rapidfuzz::levenshtein_normalized_similarity(s1, s2, weights, score_cutoff);
     double res2 = rapidfuzz::levenshtein_normalized_similarity(s1.begin(), s1.end(), s2.begin(), s2.end(),
                                                                weights, score_cutoff);
+    double res3 = rapidfuzz::levenshtein_normalized_similarity(
+        BidirectionalIterWrapper(s1.begin()), BidirectionalIterWrapper(s1.end()),
+        BidirectionalIterWrapper(s2.begin()), BidirectionalIterWrapper(s2.end()), weights, score_cutoff);
     rapidfuzz::CachedLevenshtein scorer(s1, weights);
-    double res3 = scorer.normalized_similarity(s2, score_cutoff);
-    double res4 = scorer.normalized_similarity(s2.begin(), s2.end(), score_cutoff);
+    double res4 = scorer.normalized_similarity(s2, score_cutoff);
+    double res5 = scorer.normalized_similarity(s2.begin(), s2.end(), score_cutoff);
     REQUIRE(res1 == Catch::Approx(res2).epsilon(0.0001));
     REQUIRE(res1 == Catch::Approx(res3).epsilon(0.0001));
     REQUIRE(res1 == Catch::Approx(res4).epsilon(0.0001));
+    REQUIRE(res1 == Catch::Approx(res5).epsilon(0.0001));
     return res1;
 }
 
@@ -340,7 +342,7 @@ TEST_CASE("Levenshtein small band")
         REQUIRE(s2 == rapidfuzz::editops_apply<char>(ops1, s1, s2));
         rapidfuzz::Editops ops2;
         rapidfuzz::detail::levenshtein_align(ops2, rapidfuzz::detail::Range(s1), rapidfuzz::detail::Range(s2),
-                                             static_cast<int64_t>(ops1.size()));
+                                             ops1.size());
         REQUIRE(ops1 == ops2);
     }
 
@@ -388,7 +390,7 @@ TEST_CASE("Levenshtein small band")
         REQUIRE(s2 == rapidfuzz::editops_apply<char>(ops1, s1, s2));
         rapidfuzz::Editops ops2;
         rapidfuzz::detail::levenshtein_align(ops2, rapidfuzz::detail::Range(s1), rapidfuzz::detail::Range(s2),
-                                             static_cast<int64_t>(ops1.size()));
+                                             ops1.size());
         REQUIRE(ops1 == ops2);
     }
 }
@@ -408,7 +410,7 @@ TEST_CASE("Levenshtein large band")
         REQUIRE(s2 == rapidfuzz::editops_apply<uint8_t>(ops1, s1, s2));
         rapidfuzz::Editops ops2;
         rapidfuzz::detail::levenshtein_align(ops2, rapidfuzz::detail::Range(s1), rapidfuzz::detail::Range(s2),
-                                             static_cast<int64_t>(ops1.size()));
+                                             ops1.size());
         REQUIRE(ops1 == ops2);
     }
 
@@ -445,7 +447,7 @@ TEST_CASE("SIMD wraparound")
     scorer.insert(std::string("b"));
     scorer.insert(std::string("aa"));
     scorer.insert(std::string("bb"));
-    std::vector<int64_t> results(scorer.result_count());
+    std::vector<size_t> results(scorer.result_count());
 
     {
         std::string s2 = str_multiply(std::string("b"), 256);
@@ -479,7 +481,7 @@ TEST_CASE("SIMD")
 {
     SECTION("multiple sequences")
     {
-        std::string s2  = "0";
+        std::string s2 = "0";
         size_t count = 256 / 32 + 1;
         rapidfuzz::experimental::MultiLevenshtein<32> scorer(count);
         for (size_t i = 0; i < count - 1; ++i)
@@ -487,7 +489,7 @@ TEST_CASE("SIMD")
 
         scorer.insert(std::string("00000000000000000"));
 
-        std::vector<int64_t> results(scorer.result_count());
+        std::vector<size_t> results(scorer.result_count());
         scorer.distance(&results[0], results.size(), s2);
 
         for (size_t i = 0; i < count - 1; ++i)
