@@ -46,6 +46,7 @@ public:
     if(m_socket.is_open())
     {
       boost::asio::post(m_context, [this] {
+        m_socket.shutdown(boost::asio::local::datagram_protocol::socket::shutdown_both);
         m_socket.close();
         on_close();
       });
@@ -101,7 +102,11 @@ public:
   {
   }
 
-  void close() { m_socket.close(); }
+  void close()
+  {
+    m_socket.shutdown(boost::asio::local::stream_protocol::socket::shutdown_both);
+    m_socket.close();
+  }
 
   void write(const boost::asio::const_buffer& buf) { boost::asio::write(m_socket, buf); }
 
@@ -165,6 +170,7 @@ public:
   void close()
   {
     boost::asio::post(m_context, [this] {
+      m_socket.shutdown(boost::asio::local::stream_protocol::socket::shutdown_both);
       m_socket.close();
       on_close();
     });
