@@ -9,19 +9,10 @@ extern "C" {
 #endif
 
 #define PD_MAJOR_VERSION 0
-#define PD_MINOR_VERSION 55
-#define PD_BUGFIX_VERSION 0
+#define PD_MINOR_VERSION 54
+#define PD_BUGFIX_VERSION 1
 #define PD_TEST_VERSION ""
 
-/* compile-time version check:
-   #if PD_VERSION_CODE < PD_VERSION(0, 56, 0)
-      // put legacy code for Pd<<0.56 in here
-   #endif
- */
-#define PD_VERSION(major, minor, bugfix) \
-    (((major) << 16) + ((minor) << 8) + ((bugfix) > 255 ? 255 : (bugfix)))
-#define PD_VERSION_CODE PD_VERSION(PD_MAJOR_VERSION, PD_MINOR_VERSION, PD_BUGFIX_VERSION)
-
 /* old name for "MSW" flag -- we have to take it for the sake of many old
 "nmakefiles" for externs, which will define NT and not MSW */
 #if defined(NT) && !defined(MSW)
@@ -60,19 +51,6 @@ extern "C" {
 #define EXTERN_STRUCT struct
 #endif
 
-
-/* util for better inlining of static functions in headers */
-#if defined(__cplusplus)
-# define PD_INLINE inline
-#else
-# if (__STDC_VERSION__ >= 199901L)
-#  define PD_INLINE static inline
-# else
-#  define PD_INLINE static
-# endif
-#endif
-
-
 /* Define some attributes, specific to the compiler */
 #if defined(__GNUC__)
 #define ATTRIBUTE_FORMAT_PRINTF(a, b) __attribute__ ((format (printf, a, b)))
@@ -80,33 +58,10 @@ extern "C" {
 #define ATTRIBUTE_FORMAT_PRINTF(a, b)
 #endif
 
-#if __STDC_VERSION__ >= 201112L
-#include <assert.h>
-#define PD_STATIC_ASSERT _Static_assert
-#elif __cplusplus >= 201103L
-#define PD_STATIC_ASSERT static_assert
-#else
-#define PD_STATIC_ASSERT(condition, message) /* no-op */
-#endif
-
-/* deprecation warning */
-#ifndef PD_DEPRECATED
-# ifdef __GNUC__
-#  define PD_DEPRECATED __attribute__ ((deprecated))
-# elif defined(_MSC_VER) && _MSC_VER >= 1300
-#  define PD_DEPRECATED __declspec(deprecated)
-# else
-#  define PD_DEPRECATED
-#  pragma message("PD_DEPRECATED not defined for this compiler")
-# endif
-#endif
-
 #if !defined(_SIZE_T) && !defined(_SIZE_T_)
 #include <stddef.h>     /* just for size_t -- how lame! */
 #endif
 
-#include <stddef.h> /* for size_t and offsetof */
-
 /* Microsoft Visual Studio is not C99, but since VS2015 has included most C99 headers:
    https://docs.microsoft.com/en-us/previous-versions/hh409293(v=vs.140)#c-runtime-library
    These definitions recreate stdint.h types, but only in pre-2015 Visual Studio: */
@@ -126,8 +81,6 @@ typedef unsigned __int64  uint64_t;
 /* for FILE, needed by sys_fopen() and sys_fclose() only */
 #include <stdio.h>
 
-EXTERN int pd_compatibilitylevel;   /* e.g., 43 for pd 0.43 compatibility */
-
 #define MAXPDSTRING 1000        /* use this for anything you want */
 #define MAXPDARG 5              /* max number of args we can typecheck today */
 
@@ -424,7 +377,7 @@ EXTERN void clock_delay(t_clock *x, double delaytime);
 EXTERN void clock_unset(t_clock *x);
 EXTERN void clock_setunit(t_clock *x, double timeunit, int sampflag);
 EXTERN double clock_getlogicaltime(void);
-PD_DEPRECATED EXTERN double clock_getsystime(void); /* use clock_getlogicaltime() */
+EXTERN double clock_getsystime(void); /* OBSOLETE; use clock_getlogicaltime() */
 EXTERN double clock_gettimesince(double prevsystime);
 EXTERN double clock_gettimesincewithunits(double prevsystime,
     double units, int sampflag);
@@ -572,8 +525,7 @@ EXTERN int class_isdrawcommand(const t_class *c);
 EXTERN void class_set_extern_dir(t_symbol *s);
 EXTERN void class_domainsignalin(t_class *c, int onset);
 #define CLASS_MAINSIGNALIN(c, type, field) \
-    PD_STATIC_ASSERT(sizeof(((type *)NULL)->field) == sizeof(t_float), "field must be t_float!"); \
-    class_domainsignalin(c, offsetof(type, field))
+    class_domainsignalin(c, (char *)(&((type *)0)->field) - (char *)0)
 
          /* prototype for functions to save Pd's to a binbuf */
 typedef void (*t_savefn)(t_gobj *x, t_binbuf *b);
@@ -626,7 +578,8 @@ typedef enum {
 EXTERN void logpost(const void *object, int level, const char *fmt, ...)
     ATTRIBUTE_FORMAT_PRINTF(3, 4);
 
-PD_DEPRECATED EXTERN void verbose(int level, const char *fmt, ...) ATTRIBUTE_FORMAT_PRINTF(2, 3); /* avoid this: use logpost() instead */
+/* deprecated, use logpost() instead. */
+EXTERN void verbose(int level, const char *fmt, ...) ATTRIBUTE_FORMAT_PRINTF(2, 3);
 
 
 /* ------------  system interface routines ------------------- */
@@ -720,6 +673,10 @@ EXTERN void mayer_ifft(int n, t_sample *real, t_sample *imag);
 EXTERN void mayer_realfft(int n, t_sample *real);
 EXTERN void mayer_realifft(int n, t_sample *real);
 
+EXTERN float *cos_table;
+#define LOGCOSTABSIZE 9
+#define COSTABSIZE (1<<LOGCOSTABSIZE)
+
 EXTERN int canvas_suspend_dsp(void);
 EXTERN void canvas_resume_dsp(int oldstate);
 EXTERN void canvas_update_dsp(void);
@@ -772,12 +729,12 @@ EXTERN_STRUCT _garray;
 #define t_garray struct _garray
 
 EXTERN t_class *garray_class;
-PD_DEPRECATED EXTERN int garray_getfloatarray(t_garray *x, int *size, t_float **vec); /* use garray_getfloatwords() */
+EXTERN int garray_getfloatarray(t_garray *x, int *size, t_float **vec);
 EXTERN int garray_getfloatwords(t_garray *x, int *size, t_word **vec);
 EXTERN void garray_redraw(t_garray *x);
 EXTERN int garray_npoints(t_garray *x);
 EXTERN char *garray_vec(t_garray *x);
-PD_DEPRECATED EXTERN void garray_resize(t_garray *x, t_floatarg f); /* use garray_resize_long() */
+EXTERN void garray_resize(t_garray *x, t_floatarg f);  /* avoid; use this: */
 EXTERN void garray_resize_long(t_garray *x, long n);   /* better version */
 EXTERN void garray_usedindsp(t_garray *x);
 EXTERN void garray_setsaveit(t_garray *x, int saveit);
@@ -793,15 +750,15 @@ EXTERN int value_setfloat(t_symbol *s, t_float f);
 /* ------- GUI interface - functions to send strings to TK --------- */
 typedef void (*t_guicallbackfn)(t_gobj *client, t_glist *glist);
 
-PD_DEPRECATED EXTERN void sys_vgui(const char *fmt, ...); /* avoid this: use pdgui_vmess() instead */
-PD_DEPRECATED EXTERN void sys_gui(const char *s); /* avoid this: use pdgui_vmess() instead */
+EXTERN void sys_vgui(const char *fmt, ...); /* avoid this: use pdgui_vmess() instead */
+EXTERN void sys_gui(const char *s); /* avoid this: use pdgui_vmess() instead */
 
 EXTERN void sys_pretendguibytes(int n);
 EXTERN void sys_queuegui(void *client, t_glist *glist, t_guicallbackfn f);
 EXTERN void sys_unqueuegui(void *client);
     /* dialog window creation and destruction */
-PD_DEPRECATED EXTERN void gfxstub_new(t_pd *owner, void *key, const char *cmd); /* avoid this: use pdgui_stub_vnew() instead */
-PD_DEPRECATED EXTERN void gfxstub_deleteforkey(void *key); /* avoid this: use pdgui_stub_deleteforkey() instead */
+EXTERN void gfxstub_new(t_pd *owner, void *key, const char *cmd); /* avoid this: use pdgui_stub_vnew() instead */
+EXTERN void gfxstub_deleteforkey(void *key); /* avoid this: use pdgui_stub_deleteforkey() instead */
 
 /*
  * send a message to the GUI, with a simplified formatting syntax
@@ -874,12 +831,9 @@ defined, there is a "te_xpix" field in objects, not a "te_xpos" as before: */
 
 #define PD_USE_TE_XPIX
 
+#ifndef _MSC_VER /* Microoft compiler can't handle "inline" function/macros */
 #if defined(__i386__) || defined(__x86_64__) || defined(__arm__) || defined(__aarch64__)
-
-/* a test for NANs and denormals.
-   WARNING: PD_BADFLOAT(0) = 1 -- you can replace a 'BADFLOAT' by 0 but don't
-just do nothing with it. */
-
+/* a test for NANs and denormals. Should only be necessary on i386. */
 #if PD_FLOATSIZE == 32
 
 typedef union
@@ -888,7 +842,7 @@ typedef union
     unsigned int ui;
 } t_bigorsmall32;
 
-PD_INLINE int PD_BADFLOAT(t_float f)  /* malformed float */
+static inline int PD_BADFLOAT(t_float f)  /* malformed float */
 {
     t_bigorsmall32 pun;
     pun.f = f;
@@ -896,7 +850,7 @@ PD_INLINE int PD_BADFLOAT(t_float f)  /* malformed float */
     return((pun.ui == 0) | (pun.ui == 0x7f800000));
 }
 
-PD_INLINE int PD_BIGORSMALL(t_float f)  /* exponent outside (-64,64) */
+static inline int PD_BIGORSMALL(t_float f)  /* exponent outside (-64,64) */
 {
     t_bigorsmall32 pun;
     pun.f = f;
@@ -911,7 +865,7 @@ typedef union
     unsigned int ui[2];
 } t_bigorsmall64;
 
-PD_INLINE int PD_BADFLOAT(t_float f)  /* malformed double */
+static inline int PD_BADFLOAT(t_float f)  /* malformed double */
 {
     t_bigorsmall64 pun;
     pun.f = f;
@@ -919,7 +873,7 @@ PD_INLINE int PD_BADFLOAT(t_float f)  /* malformed double */
     return((pun.ui[1] == 0) | (pun.ui[1] == 0x7ff00000));
 }
 
-PD_INLINE int PD_BIGORSMALL(t_float f)  /* exponent outside (-512,512) */
+static inline int PD_BIGORSMALL(t_float f)  /* exponent outside (-512,512) */
 {
     t_bigorsmall64 pun;
     pun.f = f;
@@ -932,24 +886,23 @@ PD_INLINE int PD_BIGORSMALL(t_float f)  /* exponent outside (-512,512) */
 #define PD_BIGORSMALL(f) 0
 #endif
 
-    /* get major/minor/bugfix version numbers and version code at run time */
-EXTERN unsigned int sys_getversion(int *major, int *minor, int *bugfix);
-#ifndef PD_INTERNAL
-/* ABI compat hack: do not use _sys_getversioncode() directly! */
-PD_INLINE unsigned int _sys_getversioncode(int*major, int*minor, int*bugfix)
-{
-    int a, b, c;
-    sys_getversion(major, minor, bugfix);
-    sys_getversion(&a, &b, &c);
-    return PD_VERSION(a, b, c);
-}
-#define sys_getversion _sys_getversioncode
+#else   /* _MSC_VER */
+#if PD_FLOATSIZE == 32
+#define PD_BADFLOAT(f) ((((*(unsigned int*)&(f))&0x7f800000)==0) || \
+    (((*(unsigned int*)&(f))&0x7f800000)==0x7f800000))
+/* more stringent test: anything not between 1e-19 and 1e19 in absolute val */
+#define PD_BIGORSMALL(f) ((((*(unsigned int*)&(f))&0x60000000)==0) || \
+    (((*(unsigned int*)&(f))&0x60000000)==0x60000000))
+#else   /* 64 bits... don't know what to do here */
+#define PD_BADFLOAT(f) (!(((f) >= 0) || ((f) <= 0)))
+#define PD_BIGORSMALL(f) ((f) > 1e150 || (f) <  -1e150 \
+    || (f) > -1e-150 && (f) < 1e-150 )
 #endif
+#endif /* _MSC_VER */
 
-    /* get a Pd API function pointer by name. Returns NULL if the function
-    does not exist. For example, This allows to use recently introduced API
-    functions while providing a fallback for older Pd versions. */
-EXTERN t_method sys_getfunbyname(const char *name);
+    /* get version number at run time */
+EXTERN void sys_getversion(int *major, int *minor, int *bugfix);
+EXTERN int pd_compatibilitylevel;   /* e.g., 43 for pd 0.43 compatibility */
 
     /* get floatsize at run time */
 EXTERN unsigned int sys_getfloatsize(void);
