@@ -315,7 +315,7 @@ public:
   static inline result<directory_handle> uniquely_named_directory(const path_handle &dirpath, mode _mode = mode::write, caching _caching = caching::temporary,
                                                                   flag flags = flag::none) noexcept
   {
-    try
+    LLFIO_EXCEPTION_TRY
     {
       for(;;)
       {
@@ -327,7 +327,7 @@ public:
         }
       }
     }
-    catch(...)
+    LLFIO_EXCEPTION_CATCH_ALL
     {
       return error_from_exception();
     }
