@@ -37,6 +37,11 @@ Distributed under the Boost Software License, Version 1.0.
 #pragma clang diagnostic ignored "-Wdocumentation"  // Standardese markup confuses clang
 #endif
 
+#if defined(_MSC_VER) && !defined(__clang__)
+#pragma warning(push)
+#pragma warning(disable : 6287)  // redundant code
+#endif
+
 OUTCOME_V2_NAMESPACE_EXPORT_BEGIN
 
 template <class R, class S, class P, class NoValuePolicy>  //
@@ -1139,6 +1144,10 @@ SIGNATURE NOT RECOGNISED
 
 OUTCOME_V2_NAMESPACE_END
 
+#if defined(_MSC_VER) && !defined(__clang__)
+#pragma warning(pop)
+#endif
+
 #ifdef __clang__
 #pragma clang diagnostic pop
 #endif
