@@ -1,5 +1,6 @@
 #pragma once
 
+#include "snmalloc/aal/address.h"
 #if defined(_MSC_VER)
 #  define ALLOCATOR __declspec(allocator) __declspec(restrict)
 #elif __has_attribute(malloc)
@@ -20,8 +21,10 @@
 #  include "external_alloc.h"
 #endif
 
+#include "snmalloc/stl/utility.h"
+
 #include <string.h>
-#include <utility>
+
 namespace snmalloc
 {
   enum Boundary
@@ -777,7 +780,7 @@ namespace snmalloc
       // entry for the first chunk of memory, that states it represents a
       // large object, so we can pull the check for null off the fast path.
       const PagemapEntry& entry =
-        Config::Backend::template get_metaentry(address_cast(p_raw));
+        Config::Backend::get_metaentry(address_cast(p_raw));
 
       return sizeclass_full_to_size(entry.get_sizeclass());
 #endif
@@ -828,7 +831,7 @@ namespace snmalloc
     typename Config::ClientMeta::DataRef get_client_meta_data(void* p)
     {
       const PagemapEntry& entry =
-        Config::Backend::template get_metaentry(address_cast(p));
+        Config::Backend::get_metaentry(address_cast(p));
 
       size_t index = slab_index(entry.get_sizeclass(), address_cast(p));
 
@@ -852,7 +855,7 @@ namespace snmalloc
      * @brief Get the client meta data for the snmalloc allocation covering this
      * pointer.
      */
-    std::add_const_t<typename Config::ClientMeta::DataRef>
+    stl::add_const_t<typename Config::ClientMeta::DataRef>
     get_client_meta_data_const(void* p)
     {
       const PagemapEntry& entry =
@@ -887,8 +890,18 @@ namespace snmalloc
       auto sizeclass = entry.get_sizeclass();
       return snmalloc::remaining_bytes(sizeclass, p);
 #else
-      return reinterpret_cast<size_t>(
-        std::numeric_limits<decltype(p)>::max() - p);
+      constexpr address_t mask = static_cast<address_t>(-1);
+      constexpr bool is_signed = mask < 0;
+      constexpr address_t sign_bit =
+        bits::one_at_bit<address_t>(CHAR_BIT * sizeof(address_t) - 1);
+      if constexpr (is_signed)
+      {
+        return (mask ^ sign_bit) - p;
+      }
+      else
+      {
+        return mask - p;
+      }
 #endif
     }
 
