@@ -16,7 +16,7 @@ class MultiCursorManager
 public:
   halp_meta(name, "Multi-Cursor Manager")
   halp_meta(c_name, "multicursormanager")
-  halp_meta(category, "Control/Spatialization")
+  halp_meta(category, "Spatialization")
   halp_meta(description, "Can generate a position table")
   halp_meta(manual_url, "https://ossia.io/score-docs/processes/multicursor.html")
   halp_meta(author, "Ahmed El Moudden, Société des Arts Technologiques")
