@@ -29,18 +29,38 @@ void YOLO7BlobDetector::loadClasses()
 
 void YOLO7BlobDetector::operator()()
 {
+  if (!available)
+    return;
+  if (this->inputs.model.file.bytes.empty())
+    return;
+
   auto& in_tex = inputs.image.texture;
   if (!in_tex.changed)
     return;
 
   if (!this->ctx)
-  {
-    this->ctx
-        = std::make_unique<Onnx::OnnxRunContext>(this->inputs.model.file.bytes);
-  }
+    try
+    {
+      this->ctx = std::make_unique<Onnx::OnnxRunContext>(
+          this->inputs.model.file.bytes);
+    }
+    catch (std::exception& e)
+    {
+      std::cerr << "Error while loading the model: " << e.what() << "\n";
+      available = false;
+      return;
+    }
+    catch (...)
+    {
+
+      std::cerr << "Error while loading the model\n";
+      available = false;
+      return;
+    }
+
   auto& ctx = *this->ctx;
   auto spec = ctx.readModelSpec();
-  auto t = tensorFromRGBA(
+  auto t = nchw_tensorFromRGBA(
       spec.inputs[0],
       in_tex.bytes,
       in_tex.width,
@@ -48,19 +68,28 @@ void YOLO7BlobDetector::operator()()
       this->inputs.resolution.value.x,
       this->inputs.resolution.value.y,
       storage,
-      false);
+      {0.f, 0.f, 0.f},
+      {255.f, 255.f, 255.f});
   Ort::Value tt[1] = {std::move(t.value)};
 
   assert(1 == spec.output_names_char.size());
   Ort::Value out_tt[1]{Ort::Value{nullptr}};
   ctx.infer(spec, tt, out_tt);
 
-  Yolo::YOLO_blob::processOutput_v7(
+  detector.processOutput(
       classes,
       spec,
       out_tt,
       reinterpret_cast<std::vector<Yolo::YOLO_blob::blob_type>&>(
-          outputs.detection.value));
+          outputs.detection.value),
+      0,
+      0,
+      640,
+      640,
+      640,
+      640,
+      inputs.iou_threshold,
+      inputs.confidence);
 
   auto img = Onnx::drawRects(
       inputs.image.texture.bytes,
