@@ -11,7 +11,7 @@ class Jab1D_Avnd
 {
 public:
   halp_meta(name, "Jab")
-  halp_meta(category, "Gestures")
+  halp_meta(category, "Analysis/Gestures")
   halp_meta(c_name, "puara_jab_1d_avnd")
   halp_meta(description, "Detects jab gestures from a single axis of acceleration data.")
   halp_meta(manual_url, "https://github.com/Puara/puara-gestures/")
