@@ -29,6 +29,7 @@ extern "C" void sincos(double x, double* sin, double* cos)
 }
 #endif
 
+#include <exception>
 #include <winrt/Windows.Foundation.h>
 #endif
 // clang-format on
@@ -77,6 +78,14 @@ extern "C" void sincos(double x, double* sin, double* cos)
 #define HAS_RLIMIT 1
 #endif
 
+#if __has_include(<linux/kd.h>)
+#include <linux/kd.h>
+#include <sys/ioctl.h>
+
+#include <fcntl.h>
+#include <unistd.h>
+#endif
+
 #if defined(__linux__)
 using X11ErrorHandler = int (*)(void*, void*);
 using XSetErrorHandler_ptr = X11ErrorHandler (*)(X11ErrorHandler);
@@ -177,8 +186,8 @@ static void setup_gpu()
 static void setup_x11(int argc, char** argv)
 {
 #if defined(__linux__)
-  static const bool x11 = !qgetenv("DISPLAY").isEmpty();
-  static const bool wayland = !qgetenv("WAYLAND_DISPLAY").isEmpty();
+  static const bool x11 = !qEnvironmentVariableIsEmpty("DISPLAY");
+  static const bool wayland = !qEnvironmentVariableIsEmpty("WAYLAND_DISPLAY");
   const auto platform = qgetenv("QT_QPA_PLATFORM");
   const auto platform_in_args = std::any_of(argv, argv + argc, [](std::string_view str) {
     return str == "-platform" || str == "--platform";
@@ -186,7 +195,11 @@ static void setup_x11(int argc, char** argv)
   const bool has_platform = !platform.isEmpty() || platform_in_args;
 
   if(!x11 && !wayland)
+  {
+    // Try eglfs
+    qputenv("QT_QPA_PLATFORM", "eglfs");
     return;
+  }
   static constexpr auto setup_x11_error_handling = [] {
     helper_dylibs.x11 = dlopen("libX11.so.6", RTLD_LAZY | RTLD_LOCAL);
     if(helper_dylibs.x11)
@@ -241,42 +254,64 @@ using suil_init_t = void (*)(int* argc, char*** argv, SuilArg key, ...);
 static void setup_suil()
 {
 #if defined(__linux__)
+  if(qEnvironmentVariableIsSet("SCORE_DISABLE_AUDIOPLUGINS"))
+    return;
+  if(qEnvironmentVariableIsSet("SCORE_DISABLE_LV2"))
+    return;
+  if(!helper_dylibs.run_under_x11)
+    return;
+
+  auto path = ossia::get_exe_folder();
+  if(path.ends_with("/bin"))
+    path.resize(path.size() - 4);
+
   // 1. In the appimage case we have to tell suil that libsuil_x11_in_qt6.so is
   // nrelative to the executable
-  if(qEnvironmentVariableIsEmpty("SUIL_MODULE_DIR"))
+  if(qEnvironmentVariableIsEmpty("SUIL_MODULE_DIR") && !path.empty())
   {
-    auto path = ossia::get_exe_folder();
-    if(path.empty())
-      return;
-
-    if(path.ends_with("/bin"))
-      path.resize(path.size() - 3);
-
-    path += "/lib/suil-0";
-    if(QDir{}.exists(QString::fromStdString(path)))
+    auto suil_module_dir = path + "/lib/suil-0";
+    if(QDir{}.exists(QString::fromStdString(suil_module_dir)))
     {
-      qputenv("SUIL_MODULE_DIR", path.c_str());
+      qputenv("SUIL_MODULE_DIR", suil_module_dir.c_str());
     }
   }
 
-  // 2. Init suil if necessary
-  if(auto lib = dlopen("libsuil-0.so.0", RTLD_LAZY | RTLD_LOCAL))
-  {
-    if(auto sym = reinterpret_cast<suil_init_t>(dlsym(lib, "suil_init")))
-    {
-      static int argc{0};
-      static char** argv{nullptr};
-      sym(&argc, &argv, SUIL_ARG_NONE);
-    }
-  }
-  else if(auto self = dlopen(nullptr, RTLD_LAZY | RTLD_LOCAL))
-  {
+  // 2. Init suil if necessary. We need to do this before QApplication
+  // and thus before loading libscore_plugin_lv2.so which links to the right
+  // libsuil-0.so...
+  auto init_suil = [](void* self) {
     if(auto sym = reinterpret_cast<suil_init_t>(dlsym(self, "suil_init")))
     {
       static int argc{0};
       static char** argv{nullptr};
       sym(&argc, &argv, SUIL_ARG_NONE);
+      return true;
     }
+    return false;
+  };
+
+  if(auto self = dlopen(nullptr, RTLD_LAZY | RTLD_LOCAL))
+  {
+    if(init_suil(self))
+      return;
+  }
+
+  if(QDir{}.exists(
+         QString::fromStdString(path + "/src/plugins/score-plugin-lv2/libsuil-0.so.0")))
+  {
+    if(auto lib = dlopen(
+           (path + "/src/plugins/score-plugin-lv2/libsuil-0.so.0").c_str(),
+           RTLD_LAZY | RTLD_LOCAL))
+    {
+      if(init_suil(lib))
+        return;
+    }
+  }
+
+  if(auto lib = dlopen("libsuil-0.so.0", RTLD_LAZY | RTLD_LOCAL))
+  {
+    if(init_suil(lib))
+      return;
   }
 #endif
 }
@@ -583,6 +618,33 @@ static void setup_fftw()
 static void setup_fftw() { }
 #endif
 
+// tty functions needed because when exiting with
+// eglfs and vkkhrdisplay we cannot use the keyboard anymore
+// https://stackoverflow.com/a/66526943
+#if defined(KDSKBMODE)
+static int linux_tty_k_mode = -1;
+static void read_linux_tty()
+{
+  int tfd = open("/dev/tty", O_RDWR);
+  if(tfd == -1)
+    return;
+  ioctl(tfd, KDGKBMODE, &linux_tty_k_mode);
+  close(tfd);
+}
+static void restore_linux_tty()
+{
+  int tfd = open("/dev/tty", O_RDWR);
+  if(tfd == -1)
+    return;
+  ioctl(tfd, KDSETMODE, KD_TEXT);          // return to text mode from graphics mode
+  ioctl(tfd, 0x4b51, 0);                   // 0x4b51=KDKBMUTE, from qfbvthandler.cpp
+  ioctl(tfd, KDSKBMODE, linux_tty_k_mode); // set keyboard mode back
+  linux_tty_k_mode = -1;
+  const auto blink_on = "\033[9;15]\033[?33h\033[?25h\033[?0c"; // from qfbvthandler.cpp
+  write(tfd, blink_on, strlen(blink_on) + 1); // enable blanking and cursor
+  close(tfd);
+}
+#endif
 static void setup_limits()
 {
 #if HAS_RLIMIT
@@ -684,6 +746,10 @@ int main(int argc, char** argv)
   // FIXME broken in qt6 qputenv("QT_MAC_WANTS_LAYER", "1");
 #endif
 
+#if defined(KDSKBMODE)
+  read_linux_tty();
+#endif
+
   setup_limits();
   setup_gpu();
   setup_x11(argc, argv);
@@ -703,6 +769,15 @@ int main(int argc, char** argv)
   winrt::init_apartment(winrt::apartment_type::single_threaded);
 #endif
 
+#if defined(KDSKBMODE)
+  {
+    const auto& plat = QGuiApplication::platformName();
+    const bool linux_tty_needs_restore = plat == "eglfs" || plat == "vkkhrdisplay";
+    if(linux_tty_needs_restore)
+      qAddPostRoutine([] { restore_linux_tty(); });
+  }
+#endif
+
   setup_gdk();
 
 #if defined(__APPLE__)
