@@ -13,7 +13,7 @@ template <typename Node_T>
 struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
 {
   using texture_outputs = avnd::texture_output_introspection<Node_T>;
-  Node_T state;
+  std::shared_ptr<Node_T> state;
   score::gfx::Message m_last_message{};
   ossia::time_value m_last_time{-1};
 
@@ -24,8 +24,9 @@ struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
 
   GfxRenderer(const GfxNode<Node_T>& p)
       : score::gfx::GenericNodeRenderer{p}
+      , state{std::make_shared<Node_T>()}
   {
-    prepareNewState(state, p);
+    prepareNewState<Node_T>(state, p);
   }
 
   score::gfx::TextureRenderTarget
@@ -122,11 +123,11 @@ struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
   void init(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override
   {
     auto& parent = node();
-    if constexpr(requires { state.prepare(); })
+    if constexpr(requires { state->prepare(); })
     {
       parent.processControlIn(
-          *this, state, m_last_message, parent.last_message, parent.m_ctx);
-      state.prepare();
+          *this, *state, m_last_message, parent.last_message, parent.m_ctx);
+      state->prepare();
     }
 
     const auto& mesh = renderer.defaultTriangle();
@@ -139,7 +140,7 @@ struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
 
     // Init textures for the outputs
     avnd::cpu_texture_output_introspection<Node_T>::for_all(
-        avnd::get_outputs<Node_T>(state), [&](auto& t) {
+        avnd::get_outputs<Node_T>(*state), [&](auto& t) {
           createOutput(renderer, t.texture, QSize{t.texture.width, t.texture.height});
         });
 
@@ -179,15 +180,15 @@ struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
     m_last_time = parent.last_message.token.date;
 
     parent.processControlIn(
-        *this, state, m_last_message, parent.last_message, parent.m_ctx);
+        *this, *state, m_last_message, parent.last_message, parent.m_ctx);
 
     // Run the processor
-    state();
+    (*state)();
 
     // Upload output textures
     int k = 0;
     avnd::cpu_texture_output_introspection<Node_T>::for_all(
-        avnd::get_outputs<Node_T>(state), [&](auto& t) {
+        avnd::get_outputs<Node_T>(*state), [&](auto& t) {
           uploadOutputTexture(renderer, k, t.texture, res);
           k++;
         });
@@ -196,7 +197,7 @@ struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
     res = renderer.state.rhi->nextResourceUpdateBatch();
 
     // Copy the data to the model node
-    parent.processControlOut(this->state);
+    parent.processControlOut(*this->state);
   }
 };
 
