@@ -34,8 +34,12 @@ public:
 
   void addPath(std::string_view path) override
   {
-    if(path.find("companion-bundled-modules") == std::string_view::npos)
-      add(QString::fromUtf8(path.data(), path.length()));
+    if(path.find("companion-bundled-modules") != std::string_view::npos)
+      return;
+    if(path.find("node_modules") != std::string_view::npos)
+      return;
+
+    add(QString::fromUtf8(path.data(), path.length()));
   }
 
   bool onDoubleClick(const QString& path, const score::DocumentContext& ctx) override
